@@ -1,7 +1,7 @@
-## $Id: VectorValued.pm 1990 2007-04-24 15:21:17Z moocow $
+## $Id: VectorValued.pm 5770 2011-08-31 22:07:03Z moocow $
 ##
 ## File: PDL::VectorValued.pm
-## Author: Bryan Jurish <moocow@ling.uni-potsdam.de>
+## Author: Bryan Jurish <moocow@cpan.org>
 ## Description: Vector utilities for PDL: perl side only
 ##======================================================================
 
@@ -235,7 +235,7 @@ perl by Larry Wall.
 
 =head1 AUTHOR
 
-Bryan Jurish E<lt>jurish@ling.uni-potsdam.deE<gt>
+Bryan Jurish E<lt>moocow@cpan.orgE<gt>
 
 PDL by Karl Glazebrook, Tuomas J. Lukka, Christian Soeller, and others.
 
